@@ -7,6 +7,7 @@ Created on Sun Sep 29 16:43:30 2013
 import numpy as np
 from copy import deepcopy
 
+
 def compute_RE_MNE(power_states_dict, df_appliances_test):
     '''
     INPUT
@@ -24,23 +25,27 @@ def compute_RE_MNE(power_states_dict, df_appliances_test):
      ------
      
      '''
-     
-    MNE=[]
-    RE=[]
-     
+
+    MNE = []
+    RE = []
+
     for i in range(4):
         # We have 4 cases
-        numerator={}
-        denominator={}
-        mne={}
-        re={}
+        numerator = {}
+        denominator = {}
+        mne = {}
+        re = {}
         for appliance in power_states_dict[0]['states']:
-            numerator[appliance]=np.sum(np.abs(power_states_dict[i]['power'][appliance]-    df_appliances_test[appliance].values))
-            denominator[appliance]=np.sum(df_appliances_test[appliance].values)
-            mne[appliance]=numerator[appliance]*1.0/denominator[appliance]
-            re[appliance]=np.std(power_states_dict[i]['power'][appliance]-  df_appliances_test[appliance].values)
-     
+            numerator[appliance] = np.sum(
+                np.abs(power_states_dict[i]['power'][appliance] - df_appliances_test[appliance].values))
+            denominator[appliance] = np.sum(
+                df_appliances_test[appliance].values)
+            mne[appliance] = numerator[appliance] * \
+                1.0 / denominator[appliance]
+            re[appliance] = np.std(power_states_dict[i]['power']
+                                   [appliance] - df_appliances_test[appliance].values)
+
         MNE.append(deepcopy(mne))
         RE.append(deepcopy(re))
-         
-    return [MNE,RE]         
\ No newline at end of file
+
+    return [MNE, RE]
